package com.engine.organization.util;

import com.engine.organization.entity.commom.CusWorkflowRequestInfo;
import weaver.workflow.webservices.*;

import java.util.ArrayList;
import java.util.List;

/**
 * @Author liang.cheng
 * @Date 2023/9/13 2:46 PM
 * @Description: 通用
 * @Version 1.0
 */
public class OrganizationCommonUtil {


    /**
     * @Description: 集合分割
     * @Author: liang.cheng
     * @Date: 2023/9/13 2:46 PM
     * @param: [list, batchSize]
     * @return: java.util.List<java.util.List<T>>
     */
    public static <T> List<List<T>> splitList(List<T> list, int batchSize) {
        List<List<T>> splittedLists = new ArrayList<>();
        for (int i = 0; i < list.size(); i += batchSize) {
            int endIndex = Math.min(i + batchSize, list.size());
            List<T> subList = list.subList(i, endIndex);
            splittedLists.add(subList);
        }
        return splittedLists;
    }


    /**
     * @Description: 自动创建流程
     * @Author: liang.cheng
     * @Date: 2024/4/11 6:18 PM
     * @param: [cusWq]
     * @return: java.lang.String
     */
    public static String doCreateWorkflow(CusWorkflowRequestInfo cusWq){

        //工作流程请求信息
        WorkflowRequestInfo workflowRequestInfo = new WorkflowRequestInfo();
        //请求标题
        workflowRequestInfo.setRequestName(cusWq.getWorkflowName());
        //请求重要级别
        workflowRequestInfo.setRequestLevel(cusWq.getRequestLevel());
        //显示
        workflowRequestInfo.setCanView(cusWq.isCanView());
        //创建者id
        workflowRequestInfo.setCreatorId(cusWq.getCreatorId());
        //工作流信息
        workflowRequestInfo.setWorkflowBaseInfo(cusWq.getWorkflowBaseInfo());
        //主表
        workflowRequestInfo.setWorkflowMainTableInfo(cusWq.getWorkflowMainTableInfo());
        //是否提交下一节点
        workflowRequestInfo.setIsnextflow(cusWq.getNextFlow());

        WorkflowService workflow = new WorkflowServiceImpl();
        return workflow.doCreateWorkflowRequest(workflowRequestInfo, Integer.parseInt(cusWq.getCreatorId()));
    }


    public static WorkflowRequestTableField createWorkflowRequestTableField(String fieldName, String fieldValue,boolean view) {
        WorkflowRequestTableField tableField = new WorkflowRequestTableField();
        tableField.setFieldName(fieldName);
        tableField.setFieldValue(fieldValue);
        tableField.setView(view);
        tableField.setEdit(true);
        return tableField;
    }
}
